/*! @file ThumbnailView.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

import UIKit
import VaultMobileSDK

class ThumbnailView: UIView {
    @IBOutlet var view: UIView!
    @IBOutlet weak var image: UIImageView!
    @IBOutlet weak var statusImage: UIImageView!
    @IBOutlet weak var downloadView: UIView!
    @IBOutlet weak var topConstraint: NSLayoutConstraint!
    @IBOutlet weak var leadingConstraint: NSLayoutConstraint!
    var isDownloading : Bool {
        get {
            return downloadView.isHidden
        }
        set {
            downloadView.isHidden = newValue
        }
    }
    
    enum ThumbnailAppearance {
        case inDetail
        case inDocumentList
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        setupThumbnailViewUI()
    }
    
    fileprivate func setupThumbnailViewUI() {
        Bundle.main.loadNibNamed("ThumbnailView", owner: self, options: nil)
        addSubview(self.view)
        view.frame = self.bounds
        view.layer.borderWidth = 1
        view.layer.borderColor = UIColor(red: 155/255, green: 155/255, blue: 155/255, alpha: 1).cgColor
    }

    func setCachedStatus(isCached : Bool) {
        statusImage.image = isCached ? UIImage(named: "CompleteStatusIcon") : nil
    }
    
    func setPlaceOfAppearance(_ placeOfAppearance: ThumbnailView.ThumbnailAppearance) {
        if placeOfAppearance == .inDetail {
            setConstraints(topConstraintConstant: 231, leadingConstraintConstant: 166)
        } else {
            setConstraints(topConstraintConstant: 73, leadingConstraintConstant: 49)
        }
    }
    
    fileprivate func setConstraints(topConstraintConstant : CGFloat, leadingConstraintConstant : CGFloat) {
        topConstraint.constant = topConstraintConstant
        leadingConstraint.constant = leadingConstraintConstant
    }

    
    func setupThumbnailView(document : DocumentMetadata, vault : VEVVault){
        setDownloadingView(document)
        image.setVaultDocumentThumbnailImageWithPlaceholderImage(nil, documentId: UInt(document.vaultDocumentId ?? 0), majorVersion: document.majorVersion ?? 0, minorVersion: document.minorVersion ?? 0, vault: vault)
        setCachedStatus(document, vault)
    }
    
    fileprivate func setCachedStatus(_ document: DocumentMetadata, _ vault: VEVVault) {
        CacheManager.sharedInstance.getCachedDocument(documentId: document.vaultDocumentId ?? 0, vault: vault)  { [weak self] (entries, error) in
            if (entries?.count ?? -1) > 0 {
                self?.setCachedStatus(isCached: true)
            }
        }
    }
    
    fileprivate func setDownloadingView(_ document: DocumentMetadata) {
        downloadView.isHidden = !isDocumentBeingDownloaded(document)
    }
    
    fileprivate func isDocumentBeingDownloaded(_ document : DocumentMetadata) ->Bool {
        if let documentId = document.vaultDocumentId, let isDownloading = CacheManager.sharedInstance.downloadsInProgress[documentId], isDownloading == true {return true}
        return false
    }

}
