/*! @file DocumentMetadata.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */
import Foundation

class DocumentMetadata : NSObject {

    private var values = Dictionary<String, Any?>()
    private var rawResponse =  Dictionary<String,Any?>()
    
    var name : String? {
        return rawResponse[DocumentMetadataKeys.name] as? String
    }
    
    var lifecycle : String? {
        return rawResponse[DocumentMetadataKeys.lifecycle] as? String
    }
    
    var creationDate : String? {
        if let created = rawResponse[DocumentMetadataKeys.creationDate] as? String {
             return created.formatDateString(fromFormat: "yyyy-MM-dd'T'HH:mm:ss.SSSZ", toFormat: "MM/dd/yyyy")
        } else {
            return nil
        }
    }
    
    var vaultDocumentId : Int? {
        return rawResponse[DocumentMetadataKeys.vaultDocumentId] as? Int
    }
    
    var minorVersion : UInt? {
        return rawResponse[DocumentMetadataKeys.documentMinorVersion] as? UInt
    }
    
    var majorVersion : UInt? {
        return rawResponse[DocumentMetadataKeys.documentMajorVersion] as? UInt
    }
    
    var classification : String? {
        return rawResponse[DocumentMetadataKeys.classification] as? String
    }
    
    var documentNumber : String? {
        return rawResponse[DocumentMetadataKeys.documentNumber] as? String
    }
    
    var filename : String? {
        return rawResponse[DocumentMetadataKeys.filename] as? String
    }

    var type : String? {
        return rawResponse[DocumentMetadataKeys.type] as? String
    }
    
    var subtype : String? {
        return rawResponse[DocumentMetadataKeys.subtype] as? String
    }
    
    var filesize : Double? {
        return rawResponse[DocumentMetadataKeys.fileSize] as? Double
    }
    
    var status : String? {
        return rawResponse[DocumentMetadataKeys.status] as? String
    }
    
    var version : String {
        return "\(majorVersion ?? 0).\(minorVersion ?? 0)"
    }
    

    init(document : Dictionary<String,Any>){
        super.init()
        rawResponse = document
    }
    
    func getRawResponse() -> Dictionary<String, Any?> {
        return rawResponse
    }
    
}

struct DocumentMetadataKeys {
    static let creationDate = "document_creation_date__v"
    static let lifecycle = "lifecycle__v"
    static let name = "name__v"
    static let vaultDocumentId = "id"
    static let documentMajorVersion = "major_version_number__v"
    static let documentMinorVersion = "minor_version_number__v"
    static let classification = "classification__v"
    static let documentNumber = "document_number__v"
    static let filename = "filename__v"
    static let fileSize = "size__v"
    static let type = "type__v"
    static let subtype = "subtype__v"
    static let status = "status__v"
}
