/*! @file UIRouter.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

import Foundation
import UIKit
import SideMenu
import VaultMobileSDK

class UIRouter {
    static func navigateToLogin() {
        let sb = UIStoryboard(name: "Login", bundle: nil)
        let vc = sb.instantiateViewController(withIdentifier:   "LoginViewController") as! LoginViewController
        (UIApplication.shared.delegate as? AppDelegate)?.window?.rootViewController = vc
        (UIApplication.shared.delegate as? AppDelegate)?.window?.makeKeyAndVisible()
        
    }
    
    static func navigateToDocumentList(vault : VEVVault){
        let sb = UIStoryboard(name: "Documents", bundle: nil)
        let vc = sb.instantiateViewController(withIdentifier: "DocumentsListViewController") as! DocumentsListViewController
        let model = DocumentsListModel(vault: vault, currentTabBarSelection : VaultTabBarItem.Browse)
        let vm = DocumentsListViewModel(model: model)
        vc.viewModel = vm
        let navigationController = UINavigationController(rootViewController: vc)
        
        (UIApplication.shared.delegate as? AppDelegate)?.window?.rootViewController = navigationController
        (UIApplication.shared.delegate as? AppDelegate)?.window?.makeKeyAndVisible()
    }
    
    static func navigateToDocumentDetail(fromVC : UIViewController, vault : VEVVault, document : DocumentMetadata){
        let sb = UIStoryboard(name: "DocumentDetail", bundle: nil)
        let vc = sb.instantiateViewController(withIdentifier: "DocumentDetailViewController") as! DocumentDetailViewController
        let model = DocumentDetailModel(vault: vault, documentMetadata : document)
        let vm = DocumentDetailViewModel(model: model)
        vc.viewModel = vm
        fromVC.navigationController?.pushViewController(vc, animated: true)
    }

    static func navigateToVaultPicker(fromVC : UIViewController, currentVault: VEVVault, vaultUpdatesDelegate: VaultUpdatesDelegate){
        let sb = UIStoryboard(name: "VaultPicker", bundle: nil)
        let vc = sb.instantiateViewController(withIdentifier: "Vaults") as! VaultsVC
        let model = VaultsModel(currentVault: currentVault)
        let vm = VaultsVM(model: model, vaultUpdatesDelegate: vaultUpdatesDelegate)
        vc.viewModel = vm
        let navController = UINavigationController(rootViewController: vc)
        fromVC.navigationController?.present(navController, animated: true, completion: nil)
    }
}
