/*! @file VaultsVM.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

import Foundation
import VaultMobileSDK

protocol VaultUpdatesDelegate {
    func vaultUpdated(newVault: VEVVault)
}

class VaultsVM: NSObject{
    var model: VaultsModel!
    var vaultUpdatesDelegate: VaultUpdatesDelegate
    
    init(model : VaultsModel, vaultUpdatesDelegate: VaultUpdatesDelegate){
        self.model = model
        self.vaultUpdatesDelegate = vaultUpdatesDelegate
    }
    
    var currentVaultId : UInt? {
        get {
            return model.currentVaultId
        }
        set {
            model.currentVaultId = newValue
        }
    }
    
    var cachedVaults : [VEVVault] {
        get {
            return model.cachedVaults
        }
        set {
            model.cachedVaults = newValue
        }
    }
    
    var displayVaults : [VEVVault] {
        get {
            return model.displayVaults
        }
        set {
            model.displayVaults = newValue
        }
    }
    
    func refreshCachedVaults() {
        if let cachedVaults = VEVVaultAuth.sharedInstance().currentUser?.vaults, let displayVaults = VEVVaultAuth.sharedInstance().currentUser?.vaults {
            model.cachedVaults = cachedVaults
            model.displayVaults = displayVaults
        }
    }
    

    func getStringDescribingCurrentVaultChange() -> String? {
        guard let vaultID = model.currentVaultId else {
            assertionFailure("Current Vault ID is nil")
            return stringDescribingVaultChange(vaults: model.cachedVaults)
        }
        if !cachedVaultsContainsVaultId(vaultID) {
            return stringDescribingVaultChange(vaults: model.cachedVaults)
        } else { 
            return nil
        }
    }
    
    fileprivate func cachedVaultsContainsVaultId(_ vaultID: UInt) -> Bool {
        return model.cachedVaults.map({return $0.id}).contains(vaultID)
    }
    
    fileprivate func stringDescribingVaultChange(vaults : [VEVVault]) -> String {
        if let newVault = vaults.first {
            model.currentVaultId = model.cachedVaults.first?.id
            updatedCurrentlySelectedVault(selectedVault: newVault)
            return "Previously selected default vault has changed"
        } else {
            return "No Vaults are currently available"
        }
    }
    
    func updatedCurrentlySelectedVault(selectedVault : VEVVault){
        vaultUpdatesDelegate.vaultUpdated(newVault: selectedVault)
        model.currentVaultId = selectedVault.id
    }
    
    func updateCurrentlySelectedVault(indexPath : IndexPath) {
        let selectedVault = displayVaults[indexPath.row]
        updatedCurrentlySelectedVault(selectedVault: selectedVault)
    }
    
    func filterSearch(vaultData: [VEVVault], searchText: String) -> [VEVVault] {
        if searchText.isEmpty == true {
            return vaultData
        }
        return searchForSearchTextInVaultData(searchText: searchText, vaultData: vaultData)
    }
    
    fileprivate func searchForSearchTextInVaultData(searchText : String, vaultData : [VEVVault]) -> [VEVVault] {
        let filteredVaults = vaultData.filter { (vault) -> Bool in
            let tmp: NSString = vault.name as NSString
            let range = tmp.range(of: searchText, options: NSString.CompareOptions.caseInsensitive)
            return range.location != NSNotFound
        }
        return filteredVaults
    }
}
