/*! @file DocumentMetadataTest.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

import Foundation
import XCTest
@testable import DocumentViewer
import VaultMobileSDK

class DocumentMetadataTest : XCTestCase {
    func testInitMetadata() {
        let lifecycle = "Unclassified"
        let name = "Test Document"
        let metadataDictionary : Dictionary<String, Any?> = ["document_creation_date__v" : "2018-04-21T19:51:58.520Z", "lifecycle__v" : lifecycle, "name__v" : name]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.creationDate, "04/21/2018")
        XCTAssertEqual(metadata.lifecycle, "Unclassified")
        XCTAssertEqual(metadata.name, name)
    }
    
    func testInitWithNilMetadata() {
        let metadataDictionary  = ["document_creation_date__v" : nil, "lifecycle__v" : nil, "name__v" : nil] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertNil(metadata.creationDate)
        XCTAssertNil(metadata.lifecycle)
        XCTAssertNil(metadata.name)
        XCTAssertNil(metadata.vaultDocumentId)
        XCTAssertNil(metadata.minorVersion)
        XCTAssertNil(metadata.majorVersion)
        XCTAssertNil(metadata.classification)
        XCTAssertNil(metadata.documentNumber)
        XCTAssertNil(metadata.filename)
        XCTAssertNil(metadata.type)
        XCTAssertNil(metadata.subtype)
        XCTAssertNil(metadata.filesize)
    }
    
    func testParseMinorVersion() {
        let minorVersion = UInt(1)
        let metadataDictionary = ["minor_version_number__v" : minorVersion] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.minorVersion, minorVersion)
    }
    
    func testParseMajorVersion() {
        let majorVersion = UInt(3)
        let metadataDictionary = ["major_version_number__v" : majorVersion] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.majorVersion, majorVersion)
    }
    
    func testParseDocumentId() {
        let documentId = 10
        let metadataDictionary = ["id" : documentId] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.vaultDocumentId, documentId)
    }
    
    func testParseDocumentClassification(){
        let classification = "TestDocumentClassification"
        let metadataDictionary = ["classification__v" : classification] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.classification, classification)
    }
    
    func testParseDocumentNumber(){
        let documentNumber = "SNAP-1234"
        let metadataDictionary = ["document_number__v" : documentNumber] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.documentNumber, documentNumber)
    }
    
    func testParseDocumentSubType(){
        let subtype = "TestDocumentSubtype"
        let metadataDictionary = ["subtype__v" : subtype] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.subtype, subtype)
    }
    
    func testParseDocumentType(){
        let type = "TestType"
        let metadataDictionary = ["type__v" : type] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.type, type)
    }
    
    func testParseDocumentFilesize(){
        let size : Double = 23423523
        let metadataDictionary = ["size__v" : size] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.filesize, size)
    }
    
    func testParseDocumentFilename(){
        let name = "TestFilename"
        let metadataDictionary = ["filename__v" : name] as [String : Any?]
        let metadata = DocumentMetadata(document: metadataDictionary)
        XCTAssertEqual(metadata.filename, name)
    }

}
