/*! @file DocumentDetailViewModelTest.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */
@testable import DocumentViewer
import XCTest
import Foundation
import VaultMobileSDK

class DocumentDetailViewModelTest: XCTestCase {
    
    func testInit() {
        let vault = VEVVault()
        let lifecycle = "Unclassified"
        let name = "Test Document"
        let metadataDictionary : Dictionary<String, Any> = ["major_version_number__v" : 0, "minor_version_number__v" : 1, "document_number__v" : "DocumentNumberTest", "type__v" : "testType", "subtype__v" : "testSubtype", "document_creation_date__v" : "2018-04-21T19:51:58.520Z", "lifecycle__v" : lifecycle, "name__v" : name]
        let metadata = DocumentMetadata(document: metadataDictionary)
        let model = DocumentDetailModel(vault: vault, documentMetadata: metadata)
        let vm = DocumentDetailViewModel(model: model)
        XCTAssertNotNil(model)
        XCTAssertNotNil(vm)
    }
    
    func testResponseForSection1() {
        let vault = VEVVault()
        let lifecycle = "Unclassified"
        let name = "Test Document"
        let classification = "testClassification"
        let subtype = "testSubtype"
        let type = "testType"
        let documentNumber = "DocumentNumberTest"
        let creationDate = "2018-04-21T19:51:58.520Z"
        
        let metadataDictionary : Dictionary<String, Any> = ["major_version_number__v" : UInt(0), "minor_version_number__v" : UInt(1), "document_number__v" : documentNumber, "type__v" : type , "subtype__v" : subtype, "classification__v" : classification, "document_creation_date__v" : creationDate, "lifecycle__v" : lifecycle, "name__v" : name]
        let metadata = DocumentMetadata(document: metadataDictionary)
        let model = DocumentDetailModel(vault: vault, documentMetadata: metadata)
        let vm = DocumentDetailViewModel(model: model)
        
        let row1 = vm.configurationForDocumentInfoSection(row: 1)
        XCTAssertEqual(row1.title, "Name")
        XCTAssertEqual(row1.subtitle, name)
        
        let row2 = vm.configurationForDocumentInfoSection(row: 2)
        XCTAssertEqual(row2.title, "Latest Version")
        XCTAssertEqual(row2.subtitle, "0.1")

        
        let row3 = vm.configurationForDocumentInfoSection(row: 3)
        XCTAssertEqual(row3.title, "Type")
        XCTAssertEqual(row3.subtitle, "testType>testSubtype>testClassification")
        
        
        let row4 = vm.configurationForDocumentInfoSection(row: 4)
        XCTAssertEqual(row4.title, "Document Number")
        XCTAssertEqual(row4.subtitle, documentNumber)
        
        
        let row5 = vm.configurationForDocumentInfoSection(row: 5)
        XCTAssertEqual(row5.title, "Creation Date")
        XCTAssertEqual(row5.subtitle, "04/21/2018")
        
        let rowInvalid = vm.configurationForDocumentInfoSection(row: 6)
        XCTAssertEqual(rowInvalid.title, "invalid")
        XCTAssertEqual(rowInvalid.subtitle, "invalid")
        
    }
    
    func testResponseForSection2() {
        let vault = VEVVault()
        let lifecycle = "Unclassified"
        let name = "Test Document"
        let classification = "testClassification"
        let subtype = "testSubtype"
        let type = "testType"
        let documentNumber = "DocumentNumberTest"
        let creationDate = "2018-04-21T19:51:58.520Z"
        let filename = "test.pdf"
        let fileSize : Double = 234214342
        let metadataDictionary : Dictionary<String, Any> = ["major_version_number__v" : UInt(0), "minor_version_number__v" : UInt(1), "document_number__v" : documentNumber, "type__v" : type , "subtype__v" : subtype, "classification__v" : classification, "document_creation_date__v" : creationDate, "lifecycle__v" : lifecycle, "name__v" : name, "filename__v" : filename, "size__v" : fileSize ]
        let metadata = DocumentMetadata(document: metadataDictionary)
        let model = DocumentDetailModel(vault: vault, documentMetadata: metadata)
        let vm = DocumentDetailViewModel(model: model)
        
        let row1 = vm.configurationForFileInfoSection(row: 0)
        XCTAssertEqual(row1.title, "File name")
        XCTAssertEqual(row1.subtitle, filename)
        
        let row2 = vm.configurationForFileInfoSection(row: 1)
        XCTAssertEqual(row2.title, "Size")
        XCTAssertEqual(row2.subtitle, "223.4 MB")
        
    }
    
    func testGetVault(){
        let testID = UInt(10)
        let vault = VEVVault()
        vault.id = testID
        let metadataDictionary : Dictionary<String, Any> = ["major_version_number__v" : UInt(0)]
        let metadata = DocumentMetadata(document: metadataDictionary)
        let model = DocumentDetailModel(vault: vault, documentMetadata: metadata)
        let vm = DocumentDetailViewModel(model: model)
        XCTAssertTrue(vm.vault.id == testID)
        
    }
    
    func testNumberOfRows(){
        let testID = UInt(10)
        let vault = VEVVault()
        vault.id = testID
        let metadataDictionary : Dictionary<String, Any> = ["major_version_number__v" : UInt(0)]
        let metadata = DocumentMetadata(document: metadataDictionary)
        let model = DocumentDetailModel(vault: vault, documentMetadata: metadata)
        let vm = DocumentDetailViewModel(model: model)
        XCTAssertTrue(vm.numberOfRowsForSection(section: 0) == 6)
        XCTAssertTrue(vm.numberOfRowsForSection(section: 1) == 2)
    }

}
