/*! @file DocumentListViewModelTest.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */
@testable import DocumentViewer
import XCTest
import VaultMobileSDK

class DocumentListViewModelTest: XCTestCase {

    func testInit() {
        let vault = VEVVault()
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        XCTAssertNotNil(model)
        let vm = DocumentsListViewModel(model: model)
        XCTAssertNotNil(vm)
    }
    
    func testGetQuery() {
        let vault = VEVVault()
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        let vm = DocumentsListViewModel(model: model)
        vm.serverQuery = VEVVaultServerDocumentsViewRequest(view: .favorites, vault: vault, parameters: ["start" : 0, "limit" : 20])
        XCTAssertNotNil(vm.serverQuery)
    }
    
    func testGetVault() {
        let testVaultName = "testVault"
        let vault = VEVVault()
        vault.name = testVaultName
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        let vm = DocumentsListViewModel(model: model)
        vm.vault = vault
        XCTAssertNotNil(vm.vault)
        XCTAssertEqual(vm.vault.name, testVaultName)
    }
    
    func testClearResponses() {
        let vault = VEVVault()
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        model.responses = [["Test" : "test"]]
        let vm = DocumentsListViewModel(model: model)
        vm.model.showLoadingCell = false
        XCTAssertEqual(vm.numberOfResponses(section: 0), 1)
        vm.clearResponses()
        XCTAssertEqual(vm.numberOfResponses(section: 0), 0)
    }

    func testExecuteQuerySuccess() {
        let vault = VEVVault()
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        let vm = DocumentsListViewModelAPISuccess(model: model)
        vm.serverQuery = VEVVaultServerDocumentsViewRequest(view: .cart, vault: vault, parameters: nil)
        vm.model.showLoadingCell = false
        XCTAssertEqual(vm.numberOfResponses(section: 0), 0)
        vm.executeCurrentServerQuery { (error) in
            vm.model.showLoadingCell = false
            XCTAssertNil(error, "Query not successful")
            XCTAssertEqual(vm.numberOfResponses(section: 0), 1)
        }
        vm.serverQuery?.parameters = ["start" : 1]
        vm.executeCurrentServerQuery { (error)  in
            vm.model.showLoadingCell = false
            XCTAssertNil(error, "Query not successful")
            XCTAssertEqual(vm.numberOfResponses(section: 0), 2)
        }
        vm.serverQuery?.parameters = ["start" : 0]
        vm.executeCurrentServerQuery { (error) in
            vm.model.showLoadingCell = false
            XCTAssertNil(error, "Query not successful")
            XCTAssertEqual(vm.numberOfResponses(section: 0), 1)
        }
    }
    
    func testExecuteQueryFailure() {
        let vault = VEVVault()
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        let vm = DocumentsListViewModelAPIFailure(model: model)
        vm.serverQuery =  VEVVaultServerDocumentsViewRequest(view: .cart, vault: vault, parameters: nil)
        vm.model.showLoadingCell = false
        XCTAssertEqual(vm.numberOfResponses(section: 0), 0)
        vm.executeCurrentServerQuery { (error) in
            XCTAssertNotNil(error, "Query successful")
            XCTAssertEqual(vm.numberOfResponses(section: 0), 0)
        }
    }
    
    func testGetDocumentDataForResponse(){
        let vault = VEVVault()
        let model = DocumentsListModel(vault: vault, currentTabBarSelection: VaultTabBarItem.Browse)
        let vm = DocumentsListViewModelAPISuccess(model: model)
        XCTAssertNil(vm.getDocumentDataForResponseAtRow(row: 0))
        vm.serverQuery = VEVVaultServerDocumentsViewRequest(view: .cart, vault: vault, parameters: nil)
        vm.model.showLoadingCell = false
        vm.executeCurrentServerQuery { (error) in
            vm.model.showLoadingCell = false
            XCTAssertNil(error, "Query not successful")
            XCTAssertEqual(vm.numberOfResponses(section: 0), 1)
            XCTAssertNotNil(vm.getDocumentDataForResponseAtRow(row: 0))
        }
    }
    
}
