/*! @file DocumentViewerTest.swift
 *
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */
import XCTest
import VaultMobileSDK
@testable import DocumentViewer
class DocumentViewerTest : XCTestCase {
    func createTestFile(_ docId : Int, _ vault: VEVVault, _ user: VEVUser) {
        let url = CacheManager.getDocumentFileURL(docID: docId, vault: vault, user: user)
        do {
            try FileManager.default.createDirectory(atPath: url.deletingLastPathComponent().path, withIntermediateDirectories: true)
            try "test".write(to: url, atomically: true, encoding: String.Encoding.utf8)
        } catch {
            XCTAssert(false)
        }
    }
    
    class CacheManagerDelegateTest : CacheManagerDelegate {
        var expectation : XCTestExpectation!
        init(expectation : XCTestExpectation ) {
            self.expectation = expectation
        }
        func fileCacheFinished(for documentId: Int?, error: Error?) {
            XCTAssert(error == nil)
            expectation.fulfill()
        }
        func fileRemovalFinished(for documentId: Int?, error: Error?) {
            if let error = error as NSError? {
                XCTAssert(error.domain == kCacheErrorDomain)
                XCTAssert(error.code == CacheError.removalFailed)
            }
            expectation.fulfill()
        }
    }
}
