/*! @file UIImageView+VaultMobileSDK.h
 *
 *  @copyright
 *  Copyright © 2017 Veeva Systems, Inc. All rights reserved.
 */

#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

@class VEVVault;

/*! @brief VaultMobileSDK specific extensions to UIImageView.
 */
@interface UIImageView (VaultMobileSDK)

/*! @brief Asynchronously sets the `image' property to Vault's
 *  thumbnail image for the specified document. If an error occurs,
 *  i.e., the user is not logged in, this method will fail
 *  silently. The image is cached locally for future use.
 *
 *  @param placeholderImage UIImage* The UIImage displayed while
 *  waiting to retrieve the remote thumbnail.
 *
 *  @param documentId The Vault document ID of the document.
 *
 *  @param major The major version number of the document version
 *  specified.
 *
 *  @param minor The minor version number of the document version
 *  specified.
 *
 *  @param vault The vault to retrieve the document thumbnail image
 *  from.
 */
- (void)setVaultDocumentThumbnailImageWithPlaceholderImage:(nullable UIImage *)placeholderImage
												documentId:(NSUInteger)documentId
											  majorVersion:(NSUInteger)major
											  minorVersion:(NSUInteger)minor
													 vault:(VEVVault *)vault;

@end

NS_ASSUME_NONNULL_END
