/*! @file VEVVaultCache.h
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

#import <Foundation/Foundation.h>
#import "VEVError.h"


NS_ASSUME_NONNULL_BEGIN

@class VEVVault, VEVVaultCacheEntry;

/*! @brief The block type used to call back to the application after the
 *  removeEntriesFromCache method has been invoked.
 *
 *  @param error The error object in the event an error occurred during
 *  the method invocation.
 *
 *  @see VEVVaultCache::removeEntries:handler:.
 */
typedef void (^VEVVaultCacheRemoveEntriesResultHandler)(NSError * _Nullable error);

/*! @brief The block type used to call back to the application after the
 *  removeAllEntries method has been invoked.
 *
 *  @param error The error object in the event an error occurred during
 *  the method invocation.
 *
 *  @see VEVVaultCache::removeAllEntries:.
 */
typedef void (^VEVVaultCacheRemoveAllEntriesResultHandler)(NSError * _Nullable error);

/*! @brief The abstract base class for all cache classes intended to
 *  store Vault related entities for offline access.
 */
@interface VEVVaultCache : NSObject

/*! @brief The name associated with the cache.
 */
@property (strong, nonatomic, readonly, nonnull) NSString* name;

/*! @brief The Vault associated with the cache.
 */
@property (strong, nonatomic, readonly, nonnull) VEVVault* vault;

-(instancetype) __unavailable init;

/*! @brief Removes the specified entries from the cache.
 *  
 *  @param entries An array of VEVVaultCacheEntry to be removed.
 *  
 *  @param handler The callback invoked upon completion.
 */
- (void)removeEntries:(NSArray<VEVVaultCacheEntry *>*)entries handler:(VEVVaultCacheRemoveEntriesResultHandler _Nullable)handler;

/*! @brief Removes all entries from the cache.
 *
 *  @param handler The callback invoked upon completion.
 */
- (void)removeAllEntries:(VEVVaultCacheRemoveAllEntriesResultHandler _Nullable)handler;

@end

NS_ASSUME_NONNULL_END
