/*! @file VEVVaultLocalQuery.h
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

#import "VEVVaultJSONField.h"
#import "VEVVaultOperators.h"

NS_ASSUME_NONNULL_BEGIN

/*! @brief Instances of this class are used to define queries on a
 *  VEVVaultJSONCache.
 *
 *  @details Cache queries are performed by constructing a
 *  VEVVaultLocalQuery object from one or more VEVVaultQueryCriteria,
 *  and passing the query to VEVVaultJSONCache::query:handler:. The
 *  process overall is meant to correspond closely with writing
 *  directly in a query language, as the following example
 *  demonstrates:
 *
 *		let query = VEVVaultLocalQuery.create(withExpression: [
 *			VEVVaultQueryCriteria(field: "name__v", like: "Pleasanton"),
 *			VEVVaultLogicalOperatorAnd,
 *			VEVVaultQueryCriteria(field: "pages__v", equalTo: @2)])
 *
 *		documentsJsonCache.query(localQuery, handler: { (entries, error) in
 *			print("JsonCacheEntries \(entries)")
 *		})
 *
 *   @see VEVVaultJSONCache::query:handler:.
 */
@interface VEVVaultLocalQuery : NSObject

/*! @brief Creates an instance of a VEVVaultLocalQuery from a list of
 *  VEVVaultQueryCriteria and VEVVaultLogicalOperators. The first and
 *  last elements of the list must be VEVVaultQueryCriteria and each
 *  pair of VEVVaultQueryCriteria instances must be separated by a
 *  VEVVaultLogicalOperator.
 *
 * @see VEVVaultQueryCriteria
 * @see VEVVaultLogicalOperator
 */
+ (instancetype)createWithExpression:(NSArray<id> * _Nullable )expressionComponents;

@end
NS_ASSUME_NONNULL_END
