/*! @file VEVVaultLoggerInternal.h
 *  @brief For internal use only.
 *  @copyright
 *  Copyright © 2017 Veeva Systems, Inc. All rights reserved.
 */
#import <Foundation/Foundation.h>
#import "VEVVaultAuth.h"

//We can use these #define methods directly from Objective-C but not Swift
//We require the host app to use the external functions NOT the #define
//These macros will be eventually be only exposed internally

#define __VEV_FILE_NAME__ [ [NSString stringWithFormat:@"%s", __FILE__ ] componentsSeparatedByString:@"/"].lastObject
#define __SDK_BUNDLE__  [[NSBundle bundleForClass:[VEVVaultLoggerInternal class]] bundleIdentifier]
#define __SDK_BUNDLE_LAST_COMPONENT__ [__SDK_BUNDLE__ componentsSeparatedByString:@"."].lastObject
#define __HOST_BUNDLE__ [[NSBundle mainBundle] bundleIdentifier]
#define __HOST_SDK_BUNDLE__ [NSString stringWithFormat:@"%@.%@", __HOST_BUNDLE__ , __SDK_BUNDLE_LAST_COMPONENT__ ]
//Should be [Host App Bundle ID].[Last Component of SDK Bundle ID]

#define VEVLogErrorMessage(format, ...) [[VEVVaultLoggerInternal sharedInstance] logErrorMessageWithFile:__VEV_FILE_NAME__ line:__LINE__ functionName:[NSString stringWithUTF8String:__FUNCTION__] bundleId: __HOST_SDK_BUNDLE__ message:^{ \
    return ([NSString stringWithFormat:format, ##__VA_ARGS__]); \
		}]

#define VEVLogWarningMessage(format, ...) [[VEVVaultLoggerInternal sharedInstance] logWarningMessageWithFile:__VEV_FILE_NAME__ line:__LINE__ functionName:[NSString stringWithUTF8String:__FUNCTION__] bundleId:__HOST_SDK_BUNDLE__ message:^{ \
return ([NSString stringWithFormat:format, ##__VA_ARGS__]); \
}]

#define VEVLogDebugMessage(format, ...) [[VEVVaultLoggerInternal sharedInstance] logDebugMessageWithFile:__VEV_FILE_NAME__ line:__LINE__ functionName: [NSString stringWithUTF8String:__FUNCTION__] bundleId: __HOST_SDK_BUNDLE__ message:^{ \
return ([NSString stringWithFormat:format, ##__VA_ARGS__]); \
}]

NS_ASSUME_NONNULL_BEGIN

/*! @brief This class is intended only for internal use by Veeva.
 */
@interface VEVVaultLoggerInternal : NSObject

+ (instancetype)sharedInstance;

- (void)logErrorMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function message:(NSString *(^)(void))message;
- (void)logDebugMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function message:(NSString *(^)(void))message;
- (void)logWarningMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function message:(NSString *(^)(void))message;
- (void)logInfoMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function message:(NSString *(^)(void))message;

- (void)logDataWithCompletionHandler:(void(^)(NSData* _Nullable logData))handler;
- (void)addConsoleDestination;

- (void)logErrorMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function bundleId:(NSString *)bundleId message:(NSString *(^)(void))message;
- (void)logDebugMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function bundleId:(NSString *)bundleId message:(NSString *(^)(void))message;
- (void)logWarningMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function bundleId:(NSString *)bundleId message:(NSString *(^)(void))message;
- (void)logInfoMessageWithFile:(NSString *)file line:(NSInteger)line functionName:(NSString *)function bundleId:(NSString *)bundleId message:(NSString *(^)(void))message;

- (void)startUploadProcess;
- (BOOL)shouldUploadAfterEndpoint:(NSString*)endpoint;

@end

NS_ASSUME_NONNULL_END
