/*! @file VEVVaultQueryCriteria.h
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

#import <Foundation/Foundation.h>
#import "VEVVaultOperators.h"

NS_ASSUME_NONNULL_BEGIN

/*! @brief Instances of this class are used to constuct a
 *  VEVVaultLocalQuery. Each instance represents a field/value search
 *  clause in the search expression represented by the
 *  VEVVaultLocalQuery that contains it.
 *
 *  @see VEVVaultJSONCache::openCacheWithName:vault:fields:
 *  
 *  @see VEVVaultJSONCache::query:handler:
 *  
 *  @see VEVVaultLocalQuery
 */
@interface VEVVaultQueryCriteria : NSObject

/*! @brief The name of the field to search on.
 */
@property (strong, nonatomic, readonly, nonnull) NSString* field;

/*! @brief The value to query on.
 */
@property (strong, nonatomic, readonly, nonnull) id value;

/*! @brief Constructs an 'equal to' criteria to be used in a
 *  VEVVaultJSONCache query. It matches cached responses where the
 *  value for the field is equal to \c value.
 *
 *  @param field The cache field name to compare to the value.
 *  
 *  @param value The value to compare to the value in the cache field.
 */
+ (instancetype)criteriaWithField:(NSString *)field equalTo:(id)value;

/*! @brief Constructs a 'like' criteria to be used in a
 *  VEVVaultJSONCache query. It matches cached responses where the
 *  string value for the field contains the substring \c value.
 *  
 *  @param field The cache field to compare to the value.
 *   
 *  @param value The value to compare to the value in the cache field.
 */
+ (instancetype)criteriaWithField:(NSString *)field like:(id)value;

@end

NS_ASSUME_NONNULL_END
