/*! @file VEVVaultServerDocumentsSearchRequest.h
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

#import "VEVVaultServerRequest.h"
NS_ASSUME_NONNULL_BEGIN

/*! @brief A class that wraps the Documents search Vault API endpoint.
 */
@interface VEVVaultServerDocumentsSearchRequest : VEVVaultServerRequest

/*! @brief Initializes a newly created VEVVaultServerDocumentsSearchRequest.
 *
 *  @param keywords The list of search terms to filter on. If nil, all documents are returned.
 *
 *  @param vault The specific Vault to send the request to.
 *
 *  @param parameters The parameters to be encoded and included with
 *  the request. Must either be an \c NSDictionary \c or an \c NSArray
 *  \c .
 *
 *  @see <a href="https://developer.veevavault.com/api/18.1/#retrieve-all-documents">Retrieve All Documents</a>
 */
- (instancetype )initWithKeywords:(NSArray<NSString *> * _Nullable)keywords vault:(VEVVault*)vault parameters:(NSDictionary* _Nullable)parameters;
@end
NS_ASSUME_NONNULL_END
