/*! @file VEVVaultServerRequest.h
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */
#import <Foundation/Foundation.h>
#import "VEVVaultAPI.h"
#import "VEVVaultAuth.h"

NS_ASSUME_NONNULL_BEGIN

/*! @brief Instances of this class may be instantiated directly in
 *  order to invoke arbitrary Vault endpoints. However it is intended
 *  primarily for use as a base class for reusable wrappers around
 *  a given endpoint.
 */
@interface VEVVaultServerRequest : NSObject

/*! @brief Initializes a newly created VEVVaultServerRequest. This
    method is intended to be invoked only from subclass initializers.
 *
 *  @param endpoint The Vault endpoint that will be invoked by this
 *  class.
 *
 *  @param vault The specific Vault to send the request to.
 *
 *  @param method The HTTP request method used in the request.
 *
 *  @param parameterEncoding The encoding used for parameters.
 *
 *  @param parameters The parameters to be encoded and included with
 *  the request. Must either be an \c NSDictionary \c or an \c NSArray
 *  \c .
 */
- (instancetype)initWithEndpoint:(NSString*)endpoint vault:(VEVVault*)vault method:(VEVRequestMethod)method parameterEncoding:(VEVParameterEncoding)parameterEncoding parameters:( NSDictionary* _Nullable )parameters;

/* The vault endpoint to execute the request
 */
@property (strong, nonatomic, readonly) NSString *endpoint;

/* The vault to execute the query one
 */
@property (strong, nonatomic, readonly) VEVVault *vault;

/* The HTTP method to use with the request
 */
@property (nonatomic, readonly) VEVRequestMethod method;

/* The parameter encoding to use with the parameters dictionary
 */
@property (nonatomic, readonly) VEVParameterEncoding parameterEncoding;

/*! @brief Dictionary that can be used to pass additional parameters to
 *  the Vault API.
 */
@property (strong, nonatomic, nullable) NSMutableDictionary *parameters;


@end
NS_ASSUME_NONNULL_END
