/*! @file VEVVaultServerDocumentsViewRequest.h
 *  @copyright
 *  Copyright © 2018 Veeva Systems, Inc. All rights reserved.
 */

#import "VEVVaultServerRequest.h"

NS_ASSUME_NONNULL_BEGIN

/*! @brief The view to filter on in the Documents API.
 */
typedef NS_ENUM(NSInteger, VEVVaultServerView) {
	/*! @brief My Documents filter view.
	 */
    VEVVaultServerViewMyDocuments                = 1,

	/*! @brief Favorites filter view.
	 */
    VEVVaultServerViewFavorites                  = 2,

	/*! @brief Recent Documents filter view.
	 */
    VEVVaultServerViewRecentDocuments            = 3,

	/*! @brief Cart filter view.
	 */
    VEVVaultServerViewCart                       = 4
};

/*! @brief A class that wraps the Documents named filter Vault API
 *  endpoint.
 */
@interface VEVVaultServerDocumentsViewRequest : VEVVaultServerRequest

/*! @brief Initializes a newly created
 *  VEVVaultServerDocumentsViewRequest.
 *
 *  @param view Specifies the named filter to apply to the Documents
 *  endpoint.
 *
 *  @param vault The specific Vault to send the request to.
 *
 *  @param parameters The parameters to be encoded and included with
 *  the request. Must either be an \c NSDictionary \c or an \c NSArray
 *  \c .
 *
 *  @see <a href="https://developer.veevavault.com/api/18.1/#retrieve-all-documents">Retrieve All Documents</a>
 */
- (instancetype)initWithView:(VEVVaultServerView)view vault:(VEVVault*)vault parameters:(NSDictionary* _Nullable)parameters;
@end
NS_ASSUME_NONNULL_END
