/*! @file VaultMobileSDK.h
 *  
 *  @copyright
 *  Copyright © 2017 Veeva Systems, Inc. All rights reserved.
 */

#import <UIKit/UIKit.h>

FOUNDATION_EXPORT double VaultMobileSDKVersionNumber;

FOUNDATION_EXPORT const unsigned char VaultMobileSDKVersionString[];


#ifndef _VAULT_MOBILE_SDK_
#define _VAULT_MOBILE_SDK_

#import <VaultMobileSDK/VEVError.h>
#import <VaultMobileSDK/VEVVaultAuth.h>
#import <VaultMobileSDK/VEVVaultAPI.h>
#import <VaultMobileSDK/VEVVaultCrypt.h>
#import <VaultMobileSDK/VEVSDKApplicationDelegate.h>
#import <VaultMobileSDK/UIImageView+VaultMobileSDK.h>

//Remote Query
#import <VaultMobileSDK/VEVVaultServerDocumentsViewRequest.h>
#import <VaultMobileSDK/VEVVaultServerDocumentsSearchRequest.h>
#import <VaultMobileSDK/VEVVaultServerRequest.h>

//Local Query
#import <VaultMobileSDK/VEVVaultQueryCriteria.h>
#import <VaultMobileSDK/VEVVaultLocalQuery.h>
/* #import <VaultMobileSDK/VEVDocumentQuery.h> */
/* #import <VaultMobileSDK/VEVDocumentRenditionQuery.h> */
/* #import <VaultMobileSDK/VEVDocumentAttachmentQuery.h> */
/* #import <VaultMobileSDK/VEVDocumentVersionAttachmentQuery.h> */
/* #import <VaultMobileSDK/VEVObjectRecordAttachmentQuery.h> */

//Cache
#import <VaultMobileSDK/VEVVaultCache.h>
#import <VaultMobileSDK/VEVVaultCacheEntry.h>
#import <VaultMobileSDK/VEVVaultJSONCache.h>
#import <VaultMobileSDK/VEVVaultJSONCacheEntry.h>
#import <VaultMobileSDK/VEVVaultJSONField.h>
/* #import <VaultMobileSDK/VEVVaultFileCache.h> */
/* #import <VaultMobileSDK/VEVVaultFileCacheEntry.h> */
/* #import <VaultMobileSDK/VEVDocumentCacheEntry.h> */
/* #import <VaultMobileSDK/VEVDocumentRenditionCacheEntry.h> */
/* #import <VaultMobileSDK/VEVDocumentAttachmentCacheEntry.h> */
/* #import <VaultMobileSDK/VEVDocumentVersionAttachmentCacheEntry.h> */
/* #import <VaultMobileSDK/VEVObjectRecordAttachmentCacheEntry.h> */
/* #import <VaultMobileSDK/VEVDocumentMetadata.h> */
/* #import <VaultMobileSDK/VEVDocumentRenditionMetadata.h> */
/* #import <VaultMobileSDK/VEVDocumentAttachmentMetadata.h> */
/* #import <VaultMobileSDK/VEVDocumentVersionAttachmentMetadata.h> */
/* #import <VaultMobileSDK/VEVObjectRecordAttachmentMetadata.h> */
/* #import <VaultMobileSDK/VEVVaultFileMetadata.h> */
#import <VaultMobileSDK/VEVVaultOperators.h>

#import <VaultMobileSDK/VEVVaultAuthInternal.h>
#import <VaultMobileSDK/VEVVaultLoggerInternal.h>

/*! @mainpage VaultMobileSDK for iOS
 *
 *  @section introduction Introduction
 *
 *  VaultMobileSDK is an iOS framework that simplifies connecting and
 *  interacting with Vault from an iOS application. It provides support
 *  for authorization, secure local storage for your application's
 *  documents, support for uploading those documents to Vault, and a
 *  client-side passcode lock screen.
 *
 *  ## Quick Start
 *
 *  ### Integrating VaultMobileSDK
 *
 *  First, pull the VaultMobileSDK framework into your project by
 *  following Apple's instructions for <a
 *  href="https://developer.apple.com/library/content/technotes/tn2435/_index.html#//apple_ref/doc/uid/DTS40017543-CH1-EMBED_IN_APP_SECTION">embedding
 *  a framework in iOS Apps</a>.
 *
 *  Next, import the framework in your application's `UIApplicationDelegate` class:
 *
 *      import VaultMobileSDK
 *
 *  Next, modify your application's `UIApplicationDelegate` by adding
 *  the following line somewhere in your
 *  `application:didFinishLaunchingWithOptions:` method:
 *
 *		VEVSDKApplicationDelegate.sharedInstance().application(app, didFinishLaunchingWithOptions: launchOptions)
 *
 *  ### Authentication
 *
 *  Next, find a place in your code that's convenient to run Vault
 *  authentication and then add `import VaultMobileSDK` as above. Then
 *  simply include the following call:
 *
 *		VEVVaultAuth.sharedInstance().authenticate{ (_, error) in
 *          if let error = error as NSError?  {
 *              print("Error authenticating user:\(error)")
 *          } else {
 *              print("User authenticated")
 *          }
 *       }
 *
 *  When you run your app and execute the code above you will be
 *  prompted for your Vault login credentials. Once authenticated, you
 *  will then be prompted to set a PIN code for the app. You will see
 *  the output from the callbacks in XCode's console when the SDK
 *  returns control back to your application.
 */

#endif //_VAULT_MOBILE_SDK_

