# Script to decrypt redacted emails from client.log files.
# Copyright © 2017 Veeva Systems, Inc. All rights reserved.

#!/bin/sh
set -e

PROGNAME=$(basename $0)

die() {
    echo "$PROGNAME: $*" >&2
    exit 1
}

usage() {
    if [ "$*" != "" ] ; then
        echo "Error: $*"
    fi

    cat << EOF
Usage: $PROGNAME [OPTION ...] [pem file] [encrypted string]
Decrypt a string (e.g., email address from client.log).

Options:
-h, --help          display this usage message and exit
EOF

    exit 1
}

pem_file=""
enc_str=""
while [ $# -gt 0 ] ; do
    case "$1" in
    -h|--help)
        usage
        ;;
    -*)
        usage "Unknown option '$1'"
        ;;
    *)
        if [ -z "$pem_file" ] ; then
            pem_file="$1"
        elif [ -z "$enc_str" ] ; then
            enc_str="$1"
        else
            usage "Too many arguments"
        fi
        ;;
    esac
    shift
done

if [ -z "$pem_file" ] || [ -z "$enc_str" ] ; then
    usage "Not enough arguments"
fi

if [ ! -f $pem_file ] ; then
	usage "Invalid path to private key pem file"
fi

echo -n $enc_str | xxd -r -p | openssl rsautl -decrypt -inkey $pem_file
echo ''

# cat <<EOF
# pem_file=$pem_file
# enc_str=$enc_str
# EOF
